/*
* Licensed Materials - Property of IBM Corp.
* IBM AnthillPro
* (c) Copyright IBM Corporation 2011, 2013. All Rights Reserved.
*
* U.S. Government Users Restricted Rights - Use, duplication or disclosure restricted by
* GSA ADP Schedule Contract with IBM Corp.
*/


//------------------------------------------------------------------------------
// BOILER PLATE
//------------------------------------------------------------------------------
final def isWindows = (System.getProperty('os.name') =~ /(?i)windows/).find()
final def ahptool = isWindows ? 'ahptool.cmd' : 'ahptool'

final def workDir = new File('.').canonicalFile
final def out = System.out
final def env = System.getenv()
	
//------------------------------------------------------------------------------
// RUN A COMMAND UTILITY METHOD
//------------------------------------------------------------------------------

/**
 * A convenience method for running commands and optionally parsing the stdout of that command.
 * If closure is non-null, the closure will be passed the resultant {@link Process} and is expected to deal with all IO.
 * Otherwise, the process' stdOut and stdErr are forwarded to this scripts 'stdOut' and stdIn is untouched.
 * 
 * @param message an optional message to print prior to the commandline
 * @param command the command to be used as a String[]
 * @param closure an optional closure to deal with Process IO
 */
def pb = new ProcessBuilder(['echo'] as String[]).directory(workDir)
final def runCommand = {def message, def command, def closure ->
    pb.command(command as String[])
    println()
    if (message) {
        println(message)
    }
    println("command: ${pb.command().join(' ')}")
    def proc = pb.start()
    if (closure) {
        closure(proc)
    }
    else {
        proc.consumeProcessOutput(out, out) // forward stdout and stderr
        proc.getOutputStream().close() // close stdin
    }
    proc.waitFor()
    if (proc.exitValue()) {
        throw new Exception("Command failed with exit code: "+proc.exitValue())
    }
}

//------------------------------------------------------------------------------
// PARSE PROPERTIES
//------------------------------------------------------------------------------

// use ahptool to read all properties associated with this step
def ahptoolProc = [ahptool, "getStepProperties"].execute()
ahptoolProc.consumeProcessErrorStream(System.out);
def propertiesXml = ahptoolProc.text
ahptoolProc.waitFor()
if (ahptoolProc.exitValue()) {
    throw new Exception("Failed to get step properties from ahptool: " + propertiesXml)
}
def props = [:]
new XmlSlurper().parseText(propertiesXml).property.each{ propElem ->
    props[propElem.@name.text()] = propElem.text()
}

final def filePath = props['filePath']
final def filePathAbsolute = props['filePathAbsolute']
final def fullFilePath = filePathAbsolute ? filePath : (new File(workDir, filePath)).getAbsolutePath()

final def options = ['Job':'setJobProperties','Build Life':'setBuildLifeProperties']
final def choice = props['propertyContext']




//------------------------------------------------------------------------------
// MAIN PROCESS
//------------------------------------------------------------------------------



def loadedProperties = new Properties()
loadedProperties.load(new FileInputStream(new File(fullFilePath)))

def propXml = groovy.xml.DOMBuilder.newInstance().'properties'{
	loadedProperties.each {property('name':it.key, it.value)}
}

def uploadPropsCmd = [ahptool, options.get(choice), '-']

runCommand('Uploading Property File Data', uploadPropsCmd) { proc ->
    proc.consumeProcessOutput(out, out) // forward process stdout and stderr to our stdout
    proc.withWriter{ it << propXml }
}